package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcTechnical;

/**
 * cmc技术交底Mapper接口
 * 
 * @author cmc
 * @date 2024-07-04
 */
public interface CmcTechnicalMapper 
{
    /**
     * 查询cmc技术交底
     * 
     * @param technicalId cmc技术交底主键
     * @return cmc技术交底
     */
    public CmcTechnical selectCmcTechnicalByTechnicalId(String technicalId);

    /**
     * 查询cmc技术交底列表
     * 
     * @param cmcTechnical cmc技术交底
     * @return cmc技术交底集合
     */
    public List<CmcTechnical> selectCmcTechnicalList(CmcTechnical cmcTechnical);

    /**
     * 新增cmc技术交底
     * 
     * @param cmcTechnical cmc技术交底
     * @return 结果
     */
    public int insertCmcTechnical(CmcTechnical cmcTechnical);

    /**
     * 修改cmc技术交底
     * 
     * @param cmcTechnical cmc技术交底
     * @return 结果
     */
    public int updateCmcTechnical(CmcTechnical cmcTechnical);

    /**
     * 删除cmc技术交底
     * 
     * @param technicalId cmc技术交底主键
     * @return 结果
     */
    public int deleteCmcTechnicalByTechnicalId(String technicalId);

    /**
     * 批量删除cmc技术交底
     * 
     * @param technicalIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcTechnicalByTechnicalIds(String[] technicalIds);
}
